Edeliver.Relup.Instructions (edeliver v1.9.0-rc.1) View Source
This struct represents relup instructions from the relup file
but in a more accessible way. The up and down instructions can be modified
by a Edeliver.Relup.Modification and will be written back to the relup file
by edeliver before generating the release tar.
Link to this section Summary
Types
An appup instruction from the relup file
A list of appup instructions from the relup file
Appup instructions from the relup file which can
be modified. They are separated into instructions for the upgrade and instructions for the
downgrade and will be later written back to the relup file. changed_modules contains a
list of all code modules which changed in the new version and will be loaded during the
upgrade.
Link to this section Types
Specs
instruction() :: :relup.instruction()
An appup instruction from the relup file
Specs
instructions() :: [instruction()]
A list of appup instructions from the relup file
Specs
t() :: %Edeliver.Relup.Instructions{
changed_modules: [module()],
down_instructions: instructions(),
down_version: String.t(),
up_instructions: instructions(),
up_version: String.t()
}
Appup instructions from the relup file which can
be modified. They are separated into instructions for the upgrade and instructions for the
downgrade and will be later written back to the relup file. changed_modules contains a
list of all code modules which changed in the new version and will be loaded during the
upgrade.