Edeliver.Relup.Instructions.Info (edeliver v1.9.0-rc.1) View Source
This upgrade instruction logs the given info message on the node which runs the upgrade
and in the running upgrade script which was started
by the $APP/bin/$APP upgrade $RELEASE command.
Usage:
Edeliver.Relup.Instructions.Info.modify_relup(config,
_up_message="Synchronizing nodes",
_down_message="Desynchronizing nodes",
_insert_where = &append_after_point_of_no_return/2)`Available sections are:
:check-> Checks whether upgrade is possible. Before "point of no return":suspend-> Suspends processes before the upgrade. Right after the "point of no return":upgrade-> Runs the upgrade by (un-)loading new(/old) code and updating processes and applications:resume-> Resumes processes after the upgrade that were suspended in the:suspendsection.:finished-> The upgrade finished successfully
Link to this section Summary
Functions
Callback implementation for Edeliver.Relup.RunnableInstruction.arguments/2.
Calls the run/1 function of this module
Callback implementation for Edeliver.Relup.RunnableInstruction.dependencies/0.
Callback implementation for Edeliver.Relup.RunnableInstruction.insert_where/0.
Callback implementation for Edeliver.Relup.Instruction.modify_relup/2.
Logs the message on the node which is upgraded
Link to this section Functions
Specs
arguments(
%Edeliver.Relup.Instructions{
changed_modules: term(),
down_instructions: term(),
down_version: term(),
up_instructions: term(),
up_version: term()
},
Edeliver.Relup.Config.t()
) :: term()
Callback implementation for Edeliver.Relup.RunnableInstruction.arguments/2.
Specs
call_this(arguments :: [term()]) :: Instruction.instruction() | Instruction.instructions()
Calls the run/1 function of this module
from the relup file during hot code upgrade
Specs
dependencies() :: [instruction_module :: atom()]
Callback implementation for Edeliver.Relup.RunnableInstruction.dependencies/0.
Specs
insert_where() :: Instruction.insert_fun()
Callback implementation for Edeliver.Relup.RunnableInstruction.insert_where/0.
Callback implementation for Edeliver.Relup.Instruction.modify_relup/2.
modify_relup(instructions, config, up_message \\ "", down_message \\ "", insert_where_fun \\ &append_after_point_of_no_return/2)
View SourceSpecs
modify_relup( instructions :: Edeliver.Relup.Instructions.t(), config :: Edeliver.Relup.Config.t(), up_message :: String.t(), down_message :: String.t(), insert_where :: Instruction.insert_fun() ) :: Edeliver.Relup.Instructions.t()
Specs
run(message :: String.t()) :: :ok
Logs the message on the node which is upgraded
and in the upgrade script which was started by the
$APP/bin/$APP upgrade $RELEASE command.